@@ -1,4 +1,3 @@
-# coding=utf-8
 """
 pygame-menu
 https://github.com/ppizarror/pygame-menu
@@ -6,9 +5,6 @@ https://github.com/ppizarror/pygame-menu
 EXAMPLE - TIMER CLOCK
 Example file, timer clock with in-menu options.
 
-NOTE: pygame-menu v3 will not provide new widgets or functionalities, consider
-upgrading to the latest version.
-
 License:
 -------------------------------------------------------------------------------
 The MIT License (MIT)
@@ -33,12 +29,15 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 -------------------------------------------------------------------------------
 """
 
-import os
-import datetime
-from random import randrange
+__all__ = ['main']
 
 import pygame
 import pygame_menu
+from pygame_menu.examples import create_example_window
+
+import datetime
+from random import randrange
+from typing import List, Tuple, Optional
 
 # -----------------------------------------------------------------------------
 # Constants and global variables
@@ -56,16 +55,14 @@ HELP = ['Press ESC to enable/disable Menu',
         'Press LEFT/RIGHT to move through Selectors']
 W_SIZE = 800  # Width of window size
 
-# noinspection PyTypeChecker
-surface = None  # type: pygame.Surface
-# noinspection PyTypeChecker
-timer = None  # type: list
+surface: Optional['pygame.Surface'] = None
+timer: Optional[List[float]] = None
 
 
 # -----------------------------------------------------------------------------
 # Methods
 # -----------------------------------------------------------------------------
-def mainmenu_background():
+def mainmenu_background() -> None:
     """
     Background color of the main menu, on this function user can plot
     images, play sounds, etc.
@@ -75,7 +72,7 @@ def mainmenu_background():
     surface.fill((40, 0, 40))
 
 
-def reset_timer():
+def reset_timer() -> None:
     """
     Reset timer.
 
@@ -90,7 +87,7 @@ class TestCallClassMethod(object):
     """
 
     @staticmethod
-    def update_game_settings():
+    def update_game_settings() -> None:
         """
         Class method.
 
@@ -99,40 +96,35 @@ class TestCallClassMethod(object):
         print('Update game with new settings')
 
 
-def change_color_bg(value, c=None, **kwargs):
+def change_color_bg(value: Tuple, c: Optional[Tuple] = None, **kwargs) -> None:
     """
     Change background color.
 
     :param value: Selected option (data, index)
-    :type value: tuple
     :param c: Color tuple
-    :type c: tuple
     :return: None
     """
     color, _ = value
     if c == (-1, -1, -1):  # If random color
         c = (randrange(0, 255), randrange(0, 255), randrange(0, 255))
     if kwargs['write_on_console']:
-        print('New background color: {0} ({1},{2},{3})'.format(color, *c))
+        print('New background color: {0} ({1},{2},{3})'.format(color[0], *c))
     COLOR_BACKGROUND[0] = c[0]
     COLOR_BACKGROUND[1] = c[1]
     COLOR_BACKGROUND[2] = c[2]
 
 
-def main(test=False):
+def main(test: bool = False) -> None:
     """
     Main program.
 
     :param test: Indicate function is being tested
-    :type test: bool
     :return: None
     """
 
     # -------------------------------------------------------------------------
-    # Init pygame
+    # Init
     # -------------------------------------------------------------------------
-    pygame.init()
-    os.environ['SDL_VIDEO_CENTERED'] = '1'
 
     # Write help message on console
     for m in HELP:
@@ -140,13 +132,12 @@ def main(test=False):
 
     # Create window
     global surface
-    surface = pygame.display.set_mode((W_SIZE, H_SIZE))
-    pygame.display.set_caption('Example - Timer Clock')
+    surface = create_example_window('Example - Timer Clock', (W_SIZE, H_SIZE))
 
     # Main timer and game clock
     clock = pygame.time.Clock()
     global timer
-    timer = [0.0]
+    timer = [0]
     dt = 1.0 / FPS
     timer_font = pygame_menu.font.get_font(pygame_menu.font.FONT_NEVIS, 100)
 
@@ -167,10 +158,10 @@ def main(test=False):
     )
 
     # Add widgets
-    timer_menu.add_button('Reset timer', reset_timer)
+    timer_menu.add.button('Reset timer', reset_timer)
 
     # Adds a selector (element that can handle functions)
-    timer_menu.add_selector(
+    timer_menu.add.selector(
         title='Change color ',
         items=[('Random', (-1, -1, -1)),  # Values of selector, call to change_color_bg
                ('Default', (128, 0, 128)),
@@ -179,39 +170,38 @@ def main(test=False):
         default=1,  # Optional parameter that sets default item of selector
         onchange=change_color_bg,  # Action when changing element with left/right
         onreturn=change_color_bg,  # Action when pressing return on an element
-        # Optional parameters to change_color_bg function
+        # All the following kwargs are passed to change_color_bg function
         write_on_console=True
     )
-    timer_menu.add_button('Update game object', TestCallClassMethod().update_game_settings)
-    timer_menu.add_button('Return to Menu', pygame_menu.events.BACK)
-    timer_menu.add_button('Close Menu', pygame_menu.events.CLOSE)
+    timer_menu.add.button('Update game object', TestCallClassMethod().update_game_settings)
+    timer_menu.add.button('Return to Menu', pygame_menu.events.BACK)
+    timer_menu.add.button('Close Menu', pygame_menu.events.CLOSE)
 
     # -------------------------------------------------------------------------
     # Create menus: Help
     # -------------------------------------------------------------------------
-    help_theme = pygame_menu.themes.Theme(
+    help_theme = pygame_menu.Theme(
         background_color=(30, 50, 107, 190),  # 75% opacity
         title_background_color=(120, 45, 30, 190),
         title_font=pygame_menu.font.FONT_FRANCHISE,
         title_font_size=60,
         widget_font=pygame_menu.font.FONT_FRANCHISE,
         widget_font_color=(170, 170, 170),
-        widget_font_size=45,
-        widget_shadow=False,
-        widget_shadow_position=pygame_menu.locals.POSITION_SOUTHEAST
+        widget_font_shadow=True,
+        widget_font_shadow_position=pygame_menu.locals.POSITION_SOUTHEAST,
+        widget_font_size=45
     )
 
     help_menu = pygame_menu.Menu(
         height=600,  # Fullscreen
-        onclose=pygame_menu.events.DISABLE_CLOSE,  # Pressing ESC button does nothing
         theme=help_theme,
         title='Help',
         width=800
     )
     for m in HELP:
-        help_menu.add_label(m, align=pygame_menu.locals.ALIGN_CENTER)
-    help_menu.add_vertical_margin(25)
-    help_menu.add_button('Return to Menu', pygame_menu.events.BACK)
+        help_menu.add.label(m, align=pygame_menu.locals.ALIGN_CENTER)
+    help_menu.add.vertical_margin(25)
+    help_menu.add.button('Return to Menu', pygame_menu.events.BACK)
 
     # -------------------------------------------------------------------------
     # Create menus: About
@@ -223,17 +213,17 @@ def main(test=False):
     about_theme.widget_offset = (0, 0.14)
 
     about_menu = pygame_menu.Menu(
+        center_content=False,
         height=400,
         mouse_visible=False,
-        onclose=pygame_menu.events.DISABLE_CLOSE,  # Disable menu close (ESC button)
         theme=about_theme,
         title='About',
         width=600
     )
     for m in ABOUT:
-        about_menu.add_label(m, margin=(0, 0))
-    about_menu.add_label('')
-    about_menu.add_button('Return to Menu', pygame_menu.events.BACK)
+        about_menu.add.label(m, margin=(0, 0))
+    about_menu.add.label('')
+    about_menu.add.button('Return to Menu', pygame_menu.events.BACK)
 
     # -------------------------------------------------------------------------
     # Create menus: Main menu
@@ -246,10 +236,10 @@ def main(test=False):
         width=600
     )
 
-    main_menu.add_button(timer_menu.get_title(), timer_menu)  # Add timer submenu
-    main_menu.add_button(help_menu.get_title(), help_menu)  # Add help submenu
-    main_menu.add_button(about_menu.get_title(), about_menu)  # Add about submenu
-    main_menu.add_button('Exit', pygame_menu.events.EXIT)  # Add exit function
+    main_menu.add.button(timer_menu.get_title(), timer_menu)  # Add timer submenu
+    main_menu.add.button(help_menu.get_title(), help_menu)  # Add help submenu
+    main_menu.add.button(about_menu.get_title(), about_menu)  # Add about submenu
+    main_menu.add.button('Exit', pygame_menu.events.EXIT)  # Add exit function
 
     # -------------------------------------------------------------------------
     # Main loop
@@ -260,18 +250,10 @@ def main(test=False):
         clock.tick(FPS)
         timer[0] += dt
 
-        # Application events
-        events = pygame.event.get()
-        for event in events:
-            if event.type == pygame.QUIT:
-                exit()
-            elif event.type == pygame.KEYDOWN:
-                if event.key == pygame.K_ESCAPE:
-                    main_menu.toggle()
-
-        # Title is evaluated at current level as the title of the base pointer object (main_menu)
-        # can change if user opens submenus
-        if main_menu.get_current().get_title() != 'Main Menu' or not main_menu.is_enabled():
+        # Title is evaluated at current level as the title of the base pointer
+        # object (main_menu) can change if user opens submenus
+        current_menu = main_menu.get_current()
+        if current_menu.get_title() != 'Main Menu' or not main_menu.is_enabled():
             # Draw timer
             surface.fill(COLOR_BACKGROUND)
             time_string = str(datetime.timedelta(seconds=int(timer[0])))
@@ -283,10 +265,19 @@ def main(test=False):
             # Background color if the menu is enabled and timer is hidden
             surface.fill((40, 0, 40))
 
+        # Application events
+        events = pygame.event.get()
+        for event in events:
+            if event.type == pygame.QUIT:
+                exit()
+            elif event.type == pygame.KEYDOWN:
+                if event.key == pygame.K_ESCAPE and \
+                        current_menu.get_title() == 'Main Menu':
+                    main_menu.toggle()
+
         if main_menu.is_enabled():
             main_menu.draw(surface)
-
-        main_menu.update(events)
+            main_menu.update(events)
 
         # Flip surface
         pygame.display.flip()
