@@ -1,4 +1,3 @@
-# coding=utf-8
 """
 pygame-menu
 https://github.com/ppizarror/pygame-menu
@@ -6,9 +5,6 @@ https://github.com/ppizarror/pygame-menu
 HIGHLIGHT
 Widget selection highlight box effect.
 
-NOTE: pygame-menu v3 will not provide new widgets or functionalities, consider
-upgrading to the latest version.
-
 License:
 -------------------------------------------------------------------------------
 The MIT License (MIT)
@@ -33,8 +29,14 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 -------------------------------------------------------------------------------
 """
 
+__all__ = ['HighlightSelection']
+
 import pygame
-from pygame_menu.widgets.core.selection import Selection
+import pygame_menu
+
+from pygame_menu.widgets.core import Selection
+
+from pygame_menu._types import NumberType
 
 
 class HighlightSelection(Selection):
@@ -43,40 +45,43 @@ class HighlightSelection(Selection):
 
     .. note::
 
-        Widget background color may not reach the entire selection area
+        Widget background color may not reach the entire selection area.
 
     :param border_width: Border width of the highlight box
-    :type border_width: int
     :param margin_x: X margin of selected highlight box
-    :type margin_x: int, float
-    :param margin_y: X margin of selected highlight box
-    :type margin_y: int, float
+    :param margin_y: Y margin of selected highlight box
     """
+    _border_width: int
 
-    def __init__(self,
-                 border_width=1,
-                 margin_x=16,
-                 margin_y=8
-                 ):
+    def __init__(
+            self,
+            border_width: int = 1,
+            margin_x: NumberType = 16,
+            margin_y: NumberType = 8
+    ) -> None:
         assert isinstance(border_width, int)
         assert margin_x >= 0 and margin_y >= 0
         assert border_width >= 0
         margin_x = float(margin_x)
         margin_y = float(margin_y)
         super(HighlightSelection, self).__init__(
-            margin_left=margin_x / 2 + border_width,
-            margin_right=margin_x / 2 + border_width,
-            margin_top=margin_y / 2 + border_width,
-            margin_bottom=margin_y / 2 + border_width
+            margin_left=margin_x / 2,
+            margin_right=margin_x / 2,
+            margin_top=margin_y / 2,
+            margin_bottom=margin_y / 2
         )
         self._border_width = border_width
 
     # noinspection PyMissingOrEmptyDocstring
-    def draw(self, surface, widget):
+    def draw(self, surface: 'pygame.Surface', widget: 'pygame_menu.widgets.Widget') -> 'Selection':
+        if self._border_width == 0:
+            return self
         # noinspection PyArgumentList
         pygame.draw.rect(
             surface,
             self.color,
+            # self.inflate(widget.get_rect(), inflate=(-2 * self._border_width, -2 * self._border_width)),
             self.inflate(widget.get_rect()),
             self._border_width
         )
+        return self
